Introduction | AdminLTE 3 Documentation
Description: AdminLTE v3 Documentaion

Introduction | AdminLTE v3 Documentaion

# Introduction

AdminLTE can be installed using multiple methods. Pick your favorite method from the list below. Please be sure to check the dependencies section before continuing.

#### Download

###### From Github

Visit the releases section on Github and download the latest release.

#### Command Line

###### Via NPM

    npm install admin-lte@^3.0 --save

###### Via Yarn

    yarn add admin-lte@^3.0

###### Via Composer

    composer require "almasaeed2010/adminlte=~3.0"

###### Via Git

    git clone https://github.com/ColorlibHQ/AdminLTE.git